============
Installation
============

Via `pip <https://pip.pypa.io/en/stable/>`_
-------------------------------------------
* From PyPI

.. code-block:: bash

    pip install -U aiosend

* From GitHub

.. code-block:: bash

    pip install https://github.com/vovchic17/aiosend/archive/refs/heads/main.zip

Via `uv <https://docs.astral.sh/uv/>`_
--------------------------------------
.. code-block:: bash

    uv add aiosend

Via `poetry <https://python-poetry.org/>`_
------------------------------------------
.. code-block:: bash

    poetry add aiosend